@@ -1,12 +1,11 @@
 from ...plugin import Plugin
+from ... import errors
 
 
-# TODO: limit selector levels?
-# TODO: support two-level menu items?
 class TopicsPlugin(Plugin):
-    name = "topics"
+    identity = "topics"
     priority = 60
-    profile = {
+    validity = {
         "type": "object",
         "properties": {
             "selector": {"type": "string"},
@@ -15,9 +14,12 @@ class TopicsPlugin(Plugin):
 
     # Context
 
-    @Plugin.property
+    @property
     def selector(self):
-        return self.config.get("selector", "h2, h3")
+        selector = self.config.get("selector", "h2, h3")
+        if len(selector.split(",")) > 2:
+            raise errors.Error("Maximum topic levels is 2")
+        return selector
 
     # Process
 
